@@ -1,19 +1,21 @@
 import logging
-import sys
+import os
 import re
-from typing import Tuple
-from packaging import version
+import sys
 from configparser import ConfigParser, NoSectionError
-from tempfile import mkstemp
-from shutil import move, copymode
 from os import fdopen, remove
 from pathlib import Path
+from shutil import copymode, move
+from tempfile import mkstemp
+from typing import Tuple
+
 from git import Repo  # type: ignore
+from packaging import version
 from rich import print
 
 from cookietemple.create.github_support import is_git_repo
-from cookietemple.lint.template_linter import TemplateLinter
 from cookietemple.custom_cli.questionary import cookietemple_questionary_or_dot_cookietemple
+from cookietemple.lint.template_linter import TemplateLinter
 
 log = logging.getLogger(__name__)
 
@@ -26,13 +28,15 @@ class VersionBumper:
     def __init__(self, project_dir, downgrade):
         try:
             self.parser = ConfigParser()
-            self.parser.read(f'{project_dir}/cookietemple.cfg')
-            self.CURRENT_VERSION = self.parser.get('bumpversion', 'current_version')
+            self.parser.read(f"{project_dir}/cookietemple.cfg")
+            self.CURRENT_VERSION = self.parser.get("bumpversion", "current_version")
             self.downgrade_mode = downgrade
             self.top_level_dir = project_dir
         except (KeyError, NoSectionError):
-            print(f'[bold red]No cookietemple.cfg file was found at [bold blue]{project_dir} [bold red]or your cookietemple.cfg file missing required '
-                  f'bump-version section.\nPlease refer to the bump-version documentation for more information!')
+            print(
+                f"[bold red]No cookietemple.cfg file was found at [bold blue]{project_dir} [bold red]or your cookietemple.cfg file missing required "
+                f"bump-version section.\nPlease refer to the bump-version documentation for more information!"
+            )
             sys.exit(1)
 
     def bump_template_version(self, new_version: str, project_dir: Path) -> None:
@@ -49,46 +53,57 @@ class VersionBumper:
                              bumps the version from the projects top level directory. If this is not the case this parameter
                              shows the path where the projects top level directory is and bumps the version there
         """
-        log.debug(f'Current version: {self.CURRENT_VERSION} --- New version: {new_version}')
-        sections = ['bumpversion_files_whitelisted', 'bumpversion_files_blacklisted']
+        log.debug(f"Current version: {self.CURRENT_VERSION} --- New version: {new_version}")
+        sections = ["bumpversion_files_whitelisted", "bumpversion_files_blacklisted"]
 
         # if project_dir was given as handle use cwd since we need it for git add
-        ct_cfg_path = f'{str(project_dir)}/cookietemple.cfg' if str(project_dir).startswith(str(Path.cwd())) else \
-            f'{str(Path.cwd())}/{project_dir}/cookietemple.cfg'
+        ct_cfg_path = (
+            f"{str(project_dir)}/cookietemple.cfg"
+            if str(project_dir).startswith(str(Path.cwd()))
+            else f"{str(Path.cwd())}/{project_dir}/cookietemple.cfg"
+        )
 
         # keep path of all files that were changed during bump version
         changed_files = [ct_cfg_path]
 
-        print(f'[bold blue]Changing version number.\nCurrent version is {self.CURRENT_VERSION}.'
-              f'\nNew version will be {new_version}\n')
+        print(
+            f"[bold blue]Changing version number.\nCurrent version is {self.CURRENT_VERSION}."
+            f"\nNew version will be {new_version}\n"
+        )
 
         # for each section (whitelisted and blacklisted files) bump the version (if allowed)
         for section in sections:
-            log.debug(f'Bumping files of section: {section}.')
-            for file, path in self.parser.items(section):
-                not_changed, file_path = VersionBumper.replace(f'{project_dir}/{path}', new_version, section)
+            log.debug(f"Bumping files of section: {section}.")
+            for _file, path in self.parser.items(section):
+                not_changed, file_path = VersionBumper.replace(f"{project_dir}/{path}", new_version, section)
                 # only add file if the version(s) in the file were bumped
                 if not not_changed:
-                    path_changed = file_path if file_path.startswith(str(Path.cwd())) else f'{str(Path.cwd())}/{file_path}'
+                    path_changed = (
+                        file_path if file_path.startswith(str(Path.cwd())) else f"{str(Path.cwd())}/{file_path}"
+                    )
                     changed_files.append(path_changed)
 
         # update new version in cookietemple.cfg file
-        log.debug('Updating version in cookietemple.cfg file.')
-        self.parser.set('bumpversion', 'current_version', new_version)
-        with open(f'{project_dir}/cookietemple.cfg', 'w') as configfile:
+        log.debug("Updating version in cookietemple.cfg file.")
+        self.parser.set("bumpversion", "current_version", new_version)
+        # get linesep for each OS (MacOS and Linux: -1, on Windows: -2)
+        remove_chars = len(os.linesep)
+        with open(f"{project_dir}/cookietemple.cfg", "w") as configfile:
             self.parser.write(configfile)
+            # truncates the config file and removes the last new line
+            configfile.truncate(configfile.tell() - remove_chars)
 
         # check whether a project is a git repository and if so, commit bumped version changes
         if is_git_repo(project_dir):
             repo = Repo(project_dir)
 
             # git add
-            print('[bold blue]Staging template')
+            print("[bold blue]Staging template")
             repo.git.add(changed_files)
 
             # git commit
-            print('[bold blue]Committing changes to local git repository.')
-            repo.index.commit(f'Bump version from {self.CURRENT_VERSION} to {new_version}')
+            print("[bold blue]Committing changes to local git repository.")
+            repo.index.commit(f"Bump version from {self.CURRENT_VERSION} to {new_version}")
 
     @staticmethod
     def replace(file_path: str, subst: str, section: str) -> Tuple[bool, str]:
@@ -104,25 +119,29 @@ class VersionBumper:
         """
         # flag that indicates whether no changes were made inside a file
         file_is_unchanged = True
-        path_changed = ''
+        path_changed = ""
 
         # Create temp file
         fh, abs_path = mkstemp()
-        with fdopen(fh, 'w') as new_file:
+        with fdopen(fh, "w") as new_file:
             with open(file_path) as old_file:
                 for line in old_file:
                     # update version if tags were found (and were in the right section)
-                    if ('<<COOKIETEMPLE_NO_BUMP>>' not in line and not section == 'bumpversion_files_blacklisted') or '<<COOKIETEMPLE_FORCE_BUMP>>' in line:
+                    if (
+                        "<<COOKIETEMPLE_NO_BUMP>>" not in line and not section == "bumpversion_files_blacklisted"
+                    ) or "<<COOKIETEMPLE_FORCE_BUMP>>" in line:
                         # for info on this regex, see bump_template docstring above
-                        tmp = re.sub(r'(?<!\.)\d+(?:\.\d+){2}(?:-SNAPSHOT)?(?!\.)', subst, line)
+                        tmp = re.sub(r"(?<!\.)\d+(?:\.\d+){2}(?:-SNAPSHOT)?(?!\.)", subst, line)
                         new_file.write(tmp)
                         if tmp != line:
                             if file_is_unchanged:
-                                print(f'[bold blue]Updating version number in {file_path}')
+                                print(f"[bold blue]Updating version number in {file_path}")
                                 file_is_unchanged = False
                                 path_changed = file_path
-                            print(f'[bold red]- {line.strip().replace("<!-- <<COOKIETEMPLE_FORCE_BUMP>> -->", "")}\n'
-                                  + f'[bold green]+ {tmp.strip().replace("<!-- <<COOKIETEMPLE_FORCE_BUMP>> -->", "")}')
+                            print(
+                                f'[bold red]- {line.strip().replace("<!-- <<COOKIETEMPLE_FORCE_BUMP>> -->", "")}\n'
+                                + f'[bold green]+ {tmp.strip().replace("<!-- <<COOKIETEMPLE_FORCE_BUMP>> -->", "")}'
+                            )
                             print()
                     else:
                         new_file.write(line)
@@ -147,36 +166,46 @@ class VersionBumper:
         :return: True if bump version can be run, false otherwise.
         """
         # ensure that the entered version number matches correct format like 1.1.0 or 1.1.0-SNAPSHOT but not 1.2 or 1.2.3.4
-        if not re.match(r'(?<!\.)\d+(?:\.\d+){2}((?!.)|-SNAPSHOT)(?!.)', new_version):
-            print('[bold red]Invalid version specified!\n'
-                  'Ensure your version number has the form of 0.0.0 or 15.100.239-SNAPSHOT')
+        if not re.match(r"(?<!\.)\d+(?:\.\d+){2}((?!.)|-SNAPSHOT)(?!.)", new_version):
+            print(
+                "[bold red]Invalid version specified!\n"
+                "Ensure your version number has the form of 0.0.0 or 15.100.239-SNAPSHOT"
+            )
             return False
 
         # equal versions won't be accepted for bump-version
         elif new_version == self.CURRENT_VERSION:
-            print(f'[bold red]The new version {new_version} cannot be equal to the current version {self.CURRENT_VERSION}.')
+            print(
+                f"[bold red]The new version {new_version} cannot be equal to the current version {self.CURRENT_VERSION}."
+            )
             return False
 
         # only allow bump from a SNAPSHOT version to its correspondance with -SNAPSHOT removed (like 1.0.0-SNAPSHOT to 1.0.0 but not 2.0.0)
-        elif self.CURRENT_VERSION.endswith('-SNAPSHOT') and not self.CURRENT_VERSION.split('-')[0] == new_version:
-            print(f'[bold red]Cannot bump {self.CURRENT_VERSION} to {new_version}.' +
-                  f'[blue]\n{self.CURRENT_VERSION} as a SNAPSHOT version can only be bumped to its non-snapshot equivalent '
-                  f'{self.CURRENT_VERSION.split("-")[0]}.')
+        elif self.CURRENT_VERSION.endswith("-SNAPSHOT") and not self.CURRENT_VERSION.split("-")[0] == new_version:
+            print(
+                f"[bold red]Cannot bump {self.CURRENT_VERSION} to {new_version}."
+                + f"[blue]\n{self.CURRENT_VERSION} as a SNAPSHOT version can only be bumped to its non-snapshot equivalent "
+                f'{self.CURRENT_VERSION.split("-")[0]}.'
+            )
             return False
 
         # ensure the new version is greater than the current one, if not the user wants to explicitly downgrade it
         elif not self.downgrade_mode:
-            current_version_r = self.CURRENT_VERSION.replace('-SNAPSHOT', '')
-            new_version_r = new_version.replace('-SNAPSHOT', '')
+            current_version_r = self.CURRENT_VERSION.replace("-SNAPSHOT", "")
+            new_version_r = new_version.replace("-SNAPSHOT", "")
 
             # bump from x.x.x to x.x.x-SNAPSHOT should be only allowed when using the downgrade flag
-            if new_version.endswith('-SNAPSHOT') and self.CURRENT_VERSION == new_version.split('-')[0]:
-                print(f'[bold red]Cannot downgrade {self.CURRENT_VERSION} to its version SNAPSHOT {new_version}.' +
-                      f'[blue]\nUse the -d flag if you want to downgrade {self.CURRENT_VERSION} to its SNAPSHOT version.')
+            if new_version.endswith("-SNAPSHOT") and self.CURRENT_VERSION == new_version.split("-")[0]:
+                print(
+                    f"[bold red]Cannot downgrade {self.CURRENT_VERSION} to its version SNAPSHOT {new_version}."
+                    + f"[blue]\nUse the -d flag if you want to downgrade {self.CURRENT_VERSION} to its SNAPSHOT version."
+                )
                 return False
 
             # when the current version and the new version are equal, but one is a -SNAPSHOT version return true
-            elif version.parse(current_version_r) == version.parse(new_version_r) and ('-SNAPSHOT' in self.CURRENT_VERSION or '-SNAPSHOT' in new_version):
+            elif version.parse(current_version_r) == version.parse(new_version_r) and (
+                "-SNAPSHOT" in self.CURRENT_VERSION or "-SNAPSHOT" in new_version
+            ):
                 return True
 
             # else check if the new version is greater than the current version
@@ -184,8 +213,10 @@ class VersionBumper:
                 return True
 
             # the new version is not greater than the current one
-            print(f'[bold red]The new version {new_version} is not greater than the current version {self.CURRENT_VERSION}.'
-                  f'\nThe new version must be greater than the old one.')
+            print(
+                f"[bold red]The new version {new_version} is not greater than the current version {self.CURRENT_VERSION}."
+                f"\nThe new version must be greater than the old one."
+            )
             return False
 
         return True
@@ -199,26 +230,34 @@ class VersionBumper:
 
         :return: Whether it´s a reasonable bump
         """
-        cur_v_split = current_version.split('.')
-        new_v_split = new_version.split('.')
+        cur_v_split = current_version.split(".")
+        new_v_split = new_version.split(".")
 
         # major update like bumping from 1.8.3 to 2.0.0
         if new_v_split[0] != cur_v_split[0]:
-            log.debug('Identified major version bump')
-            return new_v_split[1] == '0' and new_v_split[2] == '0' and (int(new_v_split[0]) - int(cur_v_split[0]) == 1)
+            log.debug("Identified major version bump")
+            return new_v_split[1] == "0" and new_v_split[2] == "0" and (int(new_v_split[0]) - int(cur_v_split[0]) == 1)
 
         # minor update like bumping from 1.8.5 to 1.9.0
         elif new_v_split[1] != cur_v_split[1]:
-            log.debug('Identified minor version bump')
-            return new_v_split[0] == cur_v_split[0] and new_v_split[2] == '0' and (int(new_v_split[1]) - int(cur_v_split[1]) == 1)
+            log.debug("Identified minor version bump")
+            return (
+                new_v_split[0] == cur_v_split[0]
+                and new_v_split[2] == "0"
+                and (int(new_v_split[1]) - int(cur_v_split[1]) == 1)
+            )
 
         # patch update like bumping from 1.8.5 to 1.8.6
         elif new_v_split[2] != cur_v_split[2]:
-            log.debug('Identified patch version bump')
-            return new_v_split[0] == cur_v_split[0] and new_v_split[1] == cur_v_split[1] and (int(new_v_split[2]) - int(cur_v_split[2]) == 1)
+            log.debug("Identified patch version bump")
+            return (
+                new_v_split[0] == cur_v_split[0]
+                and new_v_split[1] == cur_v_split[1]
+                and (int(new_v_split[2]) - int(cur_v_split[2]) == 1)
+            )
 
         # case when we bumping like 3.0.0-SNAPSHOT to 3.0.0
-        log.debug('Identified SNAPSHOT version bump')
+        log.debug("Identified SNAPSHOT version bump")
         return True
 
     def lint_before_bump(self) -> None:
@@ -233,9 +272,11 @@ class VersionBumper:
         # if any failed linting tests, ask user for confirmation of proceeding with bump (which results in undefined behavior)
         if len(version_linter.failed) > 0 or len(version_linter.warned) > 0:
             # ask for confirmation if the user really wants to proceed bumping when linting failed
-            print('[bold red]Version check failed!\n'
-                  'You can fix them and try bumping again. Proceeding bump will result in undefined behavior!')
-            if not cookietemple_questionary_or_dot_cookietemple(function='confirm',
-                                                                question='Do you really want to continue?',
-                                                                default='n'):
+            print(
+                "[bold red]Version check failed!\n"
+                "You can fix them and try bumping again. Proceeding bump will result in undefined behavior!"
+            )
+            if not cookietemple_questionary_or_dot_cookietemple(
+                function="confirm", question="Do you really want to continue?", default="n"
+            ):
                 sys.exit(1)
