@@ -1,30 +1,32 @@
+import json
 import logging
 import os
 import sys
-from typing import Union, Tuple, Optional
+from base64 import b64encode
+from distutils.dir_util import copy_tree
+from pathlib import Path
+from subprocess import PIPE, Popen
+from typing import Any, Dict, Optional, Set, Tuple, Union
 
 import requests
-import json
-from base64 import b64encode
-from nacl import encoding, public  # type: ignore
-from pathlib import Path
 from cryptography.fernet import Fernet
-from distutils.dir_util import copy_tree
-from subprocess import Popen, PIPE
+from git import Repo, exc
 from github import Github, GithubException
-from git import Repo, exc  # type: ignore
+from nacl import encoding, public
 from ruamel.yaml import YAML
-from cookietemple.util.rich import console
 
-from cookietemple.create.domains.cookietemple_template_struct import CookietempleTemplateStruct
-from cookietemple.custom_cli.questionary import cookietemple_questionary_or_dot_cookietemple
 from cookietemple.common.load_yaml import load_yaml_file
 from cookietemple.config.config import ConfigCommand
+from cookietemple.create.domains.cookietemple_template_struct import CookietempleTemplateStruct
+from cookietemple.custom_cli.questionary import cookietemple_questionary_or_dot_cookietemple
+from cookietemple.util.rich import console
 
 log = logging.getLogger(__name__)
 
 
-def create_push_github_repository(project_path: str, creator_ctx: CookietempleTemplateStruct, tmp_repo_path: str) -> None:
+def create_push_github_repository(
+    project_path: str, creator_ctx: CookietempleTemplateStruct, tmp_repo_path: str
+) -> None:
     """
     Creates a Github repository for the created template and pushes the template to it.
     Prompts the user for the required specifications.
@@ -41,108 +43,125 @@ def create_push_github_repository(project_path: str, creator_ctx: CookietempleTe
         access_token = handle_pat_authentification()
 
         # Login to Github
-        log.debug('Logging into Github.')
-        console.print('[bold blue]Logging into Github')
+        log.debug("Logging into Github.")
+        console.print("[bold blue]Logging into Github")
         authenticated_github_user = Github(access_token)
         user = authenticated_github_user.get_user()
 
         # Create new repository
-        console.print('[bold blue]Creating Github repository')
+        console.print("[bold blue]Creating Github repository")
         if creator_ctx.is_github_orga:
-            log.debug(f'Creating a new Github repository for organizaton: {creator_ctx.github_orga}.')
+            log.debug(f"Creating a new Github repository for organizaton: {creator_ctx.github_orga}.")
             org = authenticated_github_user.get_organization(creator_ctx.github_orga)
-            repo = org.create_repo(creator_ctx.project_slug,
-                                   description=creator_ctx.project_short_description,  # type: ignore
-                                   private=creator_ctx.is_repo_private)
+            repo = org.create_repo(
+                creator_ctx.project_slug,
+                description=creator_ctx.project_short_description,  # type: ignore
+                private=creator_ctx.is_repo_private,
+            )
             creator_ctx.github_username = creator_ctx.github_orga
         else:
-            log.debug(f'Creating a new Github repository for user: {creator_ctx.github_username}.')
-            repo = user.create_repo(creator_ctx.project_slug,
-                                    description=creator_ctx.project_short_description,  # type: ignore
-                                    private=creator_ctx.is_repo_private)
+            log.debug(f"Creating a new Github repository for user: {creator_ctx.github_username}.")
+            repo = user.create_repo(
+                creator_ctx.project_slug,
+                description=creator_ctx.project_short_description,  # type: ignore
+                private=creator_ctx.is_repo_private,
+            )
 
-        console.print('[bold blue]Creating labels and default Github settings')
-        create_github_labels(repo=repo, labels=[('DEPENDABOT', '1BB0CE')])
+        console.print("[bold blue]Creating labels and default Github settings")
+        create_github_labels(repo=repo, labels=[("DEPENDABOT", "1BB0CE")])
 
-        repository = f'{tmp_repo_path}'
+        repository = f"{tmp_repo_path}"
 
         # NOTE: github_username is the organizations name, if an organization repository is to be created
 
         # create the repos sync secret
-        console.print('[bold blue]Creating repository sync secret')
+        console.print("[bold blue]Creating repository sync secret")
         create_sync_secret(creator_ctx.github_username, creator_ctx.project_slug, access_token)
 
         # git clone
-        console.print('[bold blue]Cloning empty Github repository')
-        log.debug(f'Cloning repository {creator_ctx.github_username}/{creator_ctx.project_slug}')
-        Repo.clone_from(f'https://{creator_ctx.github_username}:{access_token}@github.com/{creator_ctx.github_username}/{creator_ctx.project_slug}', repository)
+        console.print("[bold blue]Cloning empty Github repository")
+        log.debug(f"Cloning repository {creator_ctx.github_username}/{creator_ctx.project_slug}")
+        Repo.clone_from(
+            f"https://{creator_ctx.github_username}:{access_token}@github.com/{creator_ctx.github_username}/{creator_ctx.project_slug}",
+            repository,
+        )
 
-        log.debug('Copying files from the template into the cloned repository.')
+        log.debug("Copying files from the template into the cloned repository.")
         # Copy files which should be included in the initial commit -> basically the template
-        copy_tree(f'{repository}', project_path)
+        copy_tree(f"{repository}", project_path)
 
         # the created project repository with the copied .git directory
         cloned_repo = Repo(path=project_path)
 
         # git add
-        log.debug('git add')
-        console.print('[bold blue]Staging template')
+        log.debug("git add")
+        console.print("[bold blue]Staging template")
         cloned_repo.git.add(A=True)
 
         # git commit
-        log.debug('git commit')
-        cloned_repo.index.commit(f'Created {creator_ctx.project_slug} with {creator_ctx.template_handle} '
-                                 f'template of version {creator_ctx.template_version.replace("# <<COOKIETEMPLE_NO_BUMP>>", "")} using cookietemple.')
+        log.debug("git commit")
+        cloned_repo.index.commit(
+            f"Created {creator_ctx.project_slug} with {creator_ctx.template_handle} "
+            f'template of version {creator_ctx.template_version.replace("# <<COOKIETEMPLE_NO_BUMP>>", "")} using cookietemple.'
+        )
 
         # get the default branch of the repository as default branch of GitHub repositories are nor configurable by the user and can be set to any branch name
         # but cookietemple needs to know which one is the default branch in order to push to the correct remote branch and rename local branch, if necessary
-        headers = {'Authorization': f'token {access_token}'}
+        headers = {"Authorization": f"token {access_token}"}
         url = f"https://api.github.com/repos/{creator_ctx.github_username}/{creator_ctx.project_slug}"
         response = requests.get(url, headers=headers).json()
-        default_branch = response['default_branch']
-        log.debug(f'git push origin {default_branch}')
-        console.print(f'[bold blue]Pushing template to Github origin {default_branch}')
-        if default_branch != 'master':
-            cloned_repo.git.branch('-M', f'{default_branch}')
-        cloned_repo.remotes.origin.push(refspec=f'{default_branch}:{default_branch}')
+        default_branch = response["default_branch"]
+        log.debug(f"git push origin {default_branch}")
+        console.print(f"[bold blue]Pushing template to Github origin {default_branch}")
+        if default_branch != "master":
+            cloned_repo.git.branch("-M", f"{default_branch}")
+        cloned_repo.remotes.origin.push(refspec=f"{default_branch}:{default_branch}")
 
         # set branch protection (all WF must pass, dismiss stale PR reviews) only when repo is public
-        log.debug('Set branch protection rules.')
+        log.debug("Set branch protection rules.")
 
         if not creator_ctx.is_repo_private and not creator_ctx.is_github_orga:
-            main_branch = authenticated_github_user.get_user().get_repo(name=creator_ctx.project_slug).get_branch(f'{default_branch}')
+            main_branch = (
+                authenticated_github_user.get_user()
+                .get_repo(name=creator_ctx.project_slug)
+                .get_branch(f"{default_branch}")
+            )
             main_branch.edit_protection(dismiss_stale_reviews=True)
         else:
-            console.print('[bold blue]Cannot set branch protection rules due to your repository being private or an organization repo!\n'
-                          'You can set them manually later on.')
+            console.print(
+                "[bold blue]Cannot set branch protection rules due to your repository being private or an organization repo!\n"
+                "You can set them manually later on."
+            )
 
         # git create development branch
-        log.debug('git checkout -b development')
-        console.print('[bold blue]Creating development branch.')
-        cloned_repo.git.checkout('-b', 'development')
+        log.debug("git checkout -b development")
+        console.print("[bold blue]Creating development branch.")
+        cloned_repo.git.checkout("-b", "development")
 
         # git push to origin development
-        log.debug('git push origin development')
-        console.print('[bold blue]Pushing template to Github origin development.')
-        cloned_repo.remotes.origin.push(refspec='development:development')
+        log.debug("git push origin development")
+        console.print("[bold blue]Pushing template to Github origin development.")
+        cloned_repo.remotes.origin.push(refspec="development:development")
 
         # git create TEMPLATE branch
-        log.debug('git checkout -b TEMPLATE')
-        console.print('[bold blue]Creating TEMPLATE branch.')
-        cloned_repo.git.checkout('-b', 'TEMPLATE')
+        log.debug("git checkout -b TEMPLATE")
+        console.print("[bold blue]Creating TEMPLATE branch.")
+        cloned_repo.git.checkout("-b", "TEMPLATE")
 
         # git push to origin TEMPLATE
-        log.debug('git push origin TEMPLATE')
-        console.print('[bold blue]Pushing template to Github origin TEMPLATE.')
-        cloned_repo.remotes.origin.push(refspec='TEMPLATE:TEMPLATE')
+        log.debug("git push origin TEMPLATE")
+        console.print("[bold blue]Pushing template to Github origin TEMPLATE.")
+        cloned_repo.remotes.origin.push(refspec="TEMPLATE:TEMPLATE")
 
         # finally, checkout to development branch
-        log.debug('git checkout development')
-        console.print('[bold blue]Checking out development branch.')
-        cloned_repo.git.checkout('development')
+        log.debug("git checkout development")
+        console.print("[bold blue]Checking out development branch.")
+        cloned_repo.git.checkout("development")
 
         # did any errors occur?
-        console.print(f'[bold green]Successfully created a Github repository at https://github.com/{creator_ctx.github_username}/{creator_ctx.project_slug}')
+        console.print(
+            f"[bold green]Successfully created a Github repository at https://github.com/{creator_ctx.github_username}/{creator_ctx.project_slug}"
+        )
 
     except (GithubException, ConnectionError) as e:
         handle_failed_github_repo_creation(e)
@@ -156,36 +175,44 @@ def handle_pat_authentification() -> str:
     :return: The decrypted PAT
     """
     # check if the key and encrypted PAT already exist
-    log.debug(f'Attempting to read the personal access token from {ConfigCommand.CONF_FILE_PATH}')
+    log.debug(f"Attempting to read the personal access token from {ConfigCommand.CONF_FILE_PATH}")
     if os.path.exists(ConfigCommand.CONF_FILE_PATH):
         path = Path(ConfigCommand.CONF_FILE_PATH)
-        yaml = YAML(typ='safe')
+        yaml = YAML(typ="safe")
         settings = yaml.load(path)
-        if os.path.exists(ConfigCommand.KEY_PAT_FILE) and 'pat' in settings:
+        if os.path.exists(ConfigCommand.KEY_PAT_FILE) and "pat" in settings:
             pat = decrypt_pat()
             return pat
         else:
-            log.debug(f'Unable to read the personal access token from {ConfigCommand.CONF_FILE_PATH}')
-            console.print('[bold red]Could not find encrypted personal access token!\n')
-            console.print('[bold blue]Please navigate to Github -> Your profile -> Settings -> Developer Settings -> Personal access token -> '
-                          'Generate a new Token')
-            console.print('[bold blue]Only tick \'repo\'. The token is a hidden input to cookietemple and stored encrypted locally on your machine.')
-            console.print('[bold blue]For more information please read' +
-                          'https://help.github.com/en/github/authenticating-to-github/creating-a-personal-access-token-for-the-command-line\n\n')
-            console.print('[bold blue]Lets move on to set your personal access token for your cookietemple project!')
+            log.debug(f"Unable to read the personal access token from {ConfigCommand.CONF_FILE_PATH}")
+            console.print("[bold red]Could not find encrypted personal access token!\n")
+            console.print(
+                "[bold blue]Please navigate to Github -> Your profile -> Settings -> Developer Settings -> Personal access token -> "
+                "Generate a new Token"
+            )
+            console.print(
+                "[bold blue]Only tick 'repo'. The token is a hidden input to cookietemple and stored encrypted locally on your machine."
+            )
+            console.print(
+                "[bold blue]For more information please read"
+                + "https://help.github.com/en/github/authenticating-to-github/creating-a-personal-access-token-for-the-command-line\n\n"
+            )
+            console.print("[bold blue]Lets move on to set your personal access token for your cookietemple project!")
             # set the PAT
             ConfigCommand.config_pat()
             # if the user wants to create a GitHub repo but accidentally presses no on PAT config prompt
             if not os.path.exists(ConfigCommand.KEY_PAT_FILE):
-                console.print('[bold red]No Github personal access token found. Please set it using [green]cookietemple config github')
+                console.print(
+                    "[bold red]No Github personal access token found. Please set it using [green]cookietemple config github"
+                )
                 sys.exit(1)
             else:
                 pat = decrypt_pat()
             return pat
     else:
-        console.print('[bold red]Cannot find a cookietemple config file! Did you delete it?')
+        console.print("[bold red]Cannot find a cookietemple config file! Did you delete it?")
 
-    return ''
+    return ""
 
 
 def prompt_github_repo(dot_cookietemple: Optional[dict]) -> Tuple[bool, bool, bool, str]:
@@ -198,32 +225,48 @@ def prompt_github_repo(dot_cookietemple: Optional[dict]) -> Tuple[bool, bool, bo
     # if dot_cookietemple dict was passed -> return the Github related properties and do NOT prompt for them
     try:
         if dot_cookietemple:
-            if not dot_cookietemple['is_github_orga']:
-                return dot_cookietemple['is_github_repo'], dot_cookietemple['is_repo_private'], False, ''
+            if not dot_cookietemple["is_github_orga"]:
+                return dot_cookietemple["is_github_repo"], dot_cookietemple["is_repo_private"], False, ""
             else:
-                return dot_cookietemple['is_github_repo'], dot_cookietemple['is_repo_private'], dot_cookietemple['is_github_orga'], \
-                       dot_cookietemple['github_orga']
+                return (
+                    dot_cookietemple["is_github_repo"],
+                    dot_cookietemple["is_repo_private"],
+                    dot_cookietemple["is_github_orga"],
+                    dot_cookietemple["github_orga"],
+                )
     except KeyError:
-        console.print('[bold red]Missing required Github properties in .cookietemple.yml file!')
+        console.print("[bold red]Missing required Github properties in .cookietemple.yml file!")
 
     # No dot_cookietemple_dict was passed -> prompt whether to create a Github repository and the required settings
-    create_git_repo, private, is_github_org, github_org = False, False, False, ''
-    console.print('[bold blue]Automatically creating a Github repository with cookietemple is strongly recommended. '
-                  'Otherwise you will not be able to use all of cookietemple\'s features!\n')
+    create_git_repo, private, is_github_org, github_org = False, False, False, ""
+    console.print(
+        "[bold blue]Automatically creating a Github repository with cookietemple is strongly recommended. "
+        "Otherwise you will not be able to use all of cookietemple's features!\n"
+    )
 
-    if cookietemple_questionary_or_dot_cookietemple(function='confirm',
-                                                    question='Do you want to create a Github repository and push your template to it?',
-                                                    default='Yes'):
+    if cookietemple_questionary_or_dot_cookietemple(
+        function="confirm",
+        question="Do you want to create a Github repository and push your template to it?",
+        default="Yes",
+    ):
         create_git_repo = True
-        is_github_org = cookietemple_questionary_or_dot_cookietemple(function='confirm',  # type: ignore
-                                                                     question='Do you want to create an organization repository?',
-                                                                     default='No')
-        github_org = cookietemple_questionary_or_dot_cookietemple(function='text',  # type: ignore
-                                                                  question='Please enter the name of the Github organization',
-                                                                  default='SpringfieldNuclearPowerPlant') if is_github_org else ''
-        private = cookietemple_questionary_or_dot_cookietemple(function='confirm',  # type: ignore
-                                                               question='Do you want your repository to be private?',
-                                                               default='No')
+        is_github_org = cookietemple_questionary_or_dot_cookietemple(
+            function="confirm",  # type: ignore
+            question="Do you want to create an organization repository?",
+            default="No",
+        )
+        github_org = (
+            cookietemple_questionary_or_dot_cookietemple(
+                function="text",  # type: ignore
+                question="Please enter the name of the Github organization",
+                default="SpringfieldNuclearPowerPlant",
+            )
+            if is_github_org
+            else ""
+        )
+        private = cookietemple_questionary_or_dot_cookietemple(
+            function="confirm", question="Do you want your repository to be private?", default="No"  # type: ignore
+        )
     return create_git_repo, private, is_github_org, github_org
 
 
@@ -241,7 +284,7 @@ def create_sync_secret(username: str, repo_name: str, token: Union[str, bool]) -
     :param token: The PAT of the user with repo scope
     """
     public_key_dict = get_repo_public_key(username, repo_name, token)
-    create_secret(username, repo_name, token, public_key_dict['key'], public_key_dict['key_id'])
+    create_secret(username, repo_name, token, public_key_dict["key"], public_key_dict["key_id"])
 
 
 def get_repo_public_key(username: str, repo_name: str, token: Union[str, bool]) -> dict:
@@ -253,14 +296,16 @@ def get_repo_public_key(username: str, repo_name: str, token: Union[str, bool])
     :param token: The PAT of the user with repo scope
     :return: A dict containing the public key and its ID
     """
-    query_url = f'https://api.github.com/repos/{username}/{repo_name}/actions/secrets/public-key'
-    headers = {'Authorization': f'token {token}'}
+    query_url = f"https://api.github.com/repos/{username}/{repo_name}/actions/secrets/public-key"
+    headers = {"Authorization": f"token {token}"}
     r = requests.get(query_url, headers=headers)
 
     return r.json()
 
 
-def create_secret(username: str, repo_name: str, token: Union[str, bool], public_key_value: str, public_key_id: str) -> None:
+def create_secret(
+    username: str, repo_name: str, token: Union[str, bool], public_key_value: str, public_key_id: str
+) -> None:
     """
     Create the secret named CT_SYNC_TOKEN using a PUT request via the Github API. This request needs a PAT with the repo scope for authentification purposes.
     Using PyNacl, a Python binding for Javascripts LibSodium, it encrypts the secret value, which is required by the Github API.
@@ -271,17 +316,14 @@ def create_secret(username: str, repo_name: str, token: Union[str, bool], public
     :param public_key_value: The public keys value (the key) of the repos public key PyNacl uses for encryption of the secrets value
     :param public_key_id: The ID of the public key used for encryption
     """
-    log.debug('Creating Github repository secret.')
+    log.debug("Creating Github repository secret.")
     encrypted_value = encrypt_sync_secret(public_key_value, token)
     # the parameters required by the Github API
-    params = {
-        "encrypted_value": encrypted_value,
-        "key_id": public_key_id
-    }
+    params = {"encrypted_value": encrypted_value, "key_id": public_key_id}
     # the authentification header
-    headers = {'Authorization': f'token {token}'}
+    headers = {"Authorization": f"token {token}"}
     # the url used for PUT
-    put_url = f'https://api.github.com/repos/{username}/{repo_name}/actions/secrets/CT_SYNC_TOKEN'
+    put_url = f"https://api.github.com/repos/{username}/{repo_name}/actions/secrets/CT_SYNC_TOKEN"
     requests.put(put_url, headers=headers, data=json.dumps(params))
 
 
@@ -294,7 +336,7 @@ def encrypt_sync_secret(public_key: str, token: Union[str, bool]) -> str:
     :return: The encrypted secret (PAT)
     """
     """Encrypt a Unicode string using the public key."""
-    log.debug('Encrypting Github repository secret.')
+    log.debug("Encrypting Github repository secret.")
     public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
     sealed_box = public.SealedBox(public_key)
     encrypted = sealed_box.encrypt(token.encode("utf-8"))  # type: ignore
@@ -308,17 +350,17 @@ def decrypt_pat() -> str:
 
     :return: The decrypted Personal Access Token for GitHub
     """
-    log.debug(f'Decrypting personal access token using key saved in {ConfigCommand.KEY_PAT_FILE}.')
+    log.debug(f"Decrypting personal access token using key saved in {ConfigCommand.KEY_PAT_FILE}.")
     # read key and encrypted PAT from files
-    with open(ConfigCommand.KEY_PAT_FILE, 'rb') as f:
+    with open(ConfigCommand.KEY_PAT_FILE, "rb") as f:
         key = f.readline()
     fer = Fernet(key)
-    log.debug(f'Reading personal access token from {ConfigCommand.CONF_FILE_PATH}.')
-    encrypted_pat = load_yaml_file(ConfigCommand.CONF_FILE_PATH)['pat']
+    log.debug(f"Reading personal access token from {ConfigCommand.CONF_FILE_PATH}.")
+    encrypted_pat = load_yaml_file(ConfigCommand.CONF_FILE_PATH)["pat"]
     # decrypt the PAT and decode it to string
-    console.print('[bold blue]Decrypting personal access token.')
-    log.debug('Successfully decrypted personal access token.')
-    decrypted_pat = fer.decrypt(encrypted_pat).decode('utf-8')
+    console.print("[bold blue]Decrypting personal access token.")
+    log.debug("Successfully decrypted personal access token.")
+    decrypted_pat = fer.decrypt(encrypted_pat).decode("utf-8")
 
     return decrypted_pat
 
@@ -329,7 +371,7 @@ def load_github_username() -> str:
 
     :return: The users Github account name
     """
-    return load_yaml_file(ConfigCommand.CONF_FILE_PATH)['github_username']
+    return load_yaml_file(ConfigCommand.CONF_FILE_PATH)["github_username"]
 
 
 def handle_failed_github_repo_creation(e: Union[ConnectionError, GithubException]) -> None:
@@ -341,12 +383,16 @@ def handle_failed_github_repo_creation(e: Union[ConnectionError, GithubException
     """
     # output the error dict thrown by PyGitHub due to an error related to GitHub
     if isinstance(e, GithubException):
-        console.print('[bold red]\nError while trying to create a Github repo due to an error related to Github API. '
-                      'See below output for detailed information!\n')
+        console.print(
+            "[bold red]\nError while trying to create a Github repo due to an error related to Github API. "
+            "See below output for detailed information!\n"
+        )
         format_github_exception(e.data)
     # output an error that might occur due to a missing internet connection
     elif isinstance(e, ConnectionError):
-        console.print('[bold red]Error while trying to establish a connection to https://github.com. Do you have an active internet connection?')
+        console.print(
+            "[bold red]Error while trying to establish a connection to https://github.com. Do you have an active internet connection?"
+        )
 
 
 def format_github_exception(data: dict) -> None:
@@ -357,21 +403,23 @@ def format_github_exception(data: dict) -> None:
     """
     for section, description in data.items():
         if not isinstance(description, list):
-            console.print(f'[bold red]{section.capitalize()}: {description}')
+            console.print(f"[bold red]{section.capitalize()}: {description}")
         else:
-            console.print(f'[bold red]{section.upper()}: ')
-            messages = [val if not isinstance(val, dict) and not isinstance(val, set)
-                        else github_exception_dict_repr(val) for val in description]  # type: ignore
-            console.print('[bold red]\n'.join(msg for msg in messages))
+            console.print(f"[bold red]{section.upper()}: ")
+            messages = [
+                val if not isinstance(val, dict) and not isinstance(val, set) else github_exception_dict_repr(val)
+                for val in description
+            ]  # type: ignore
+            console.print("[bold red]\n".join(msg for msg in messages))
 
 
-def github_exception_dict_repr(messages: dict) -> str:
+def github_exception_dict_repr(messages: Union[Dict[Any, Any], Set[Any]]) -> str:
     """
     String representation for Github exception dict thrown by PyGitHub.
 
     :param messages: The messages as a dict
     """
-    return '\n'.join(f'    {section.capitalize()}: {description}' for section, description in messages.items())
+    return "\n".join(f"{section.capitalize()}: {description}" for section, description in messages.items())  # type: ignore
 
 
 def is_git_accessible() -> bool:
@@ -380,13 +428,13 @@ def is_git_accessible() -> bool:
 
     :return: True if accessible, false if not
     """
-    log.debug('Testing whether git is accessible.')
-    git_installed = Popen(['git', '--version'], stdout=PIPE, stderr=PIPE, universal_newlines=True)
+    log.debug("Testing whether git is accessible.")
+    git_installed = Popen(["git", "--version"], stdout=PIPE, stderr=PIPE, universal_newlines=True)
     (git_installed_stdout, git_installed_stderr) = git_installed.communicate()
     if git_installed.returncode != 0:
-        console.print('[bold red]Could not find \'git\' in the PATH. Is it installed?')
-        console.print('[bold red]Run command was: \'git --version \'')
-        log.debug('git is not accessible!')
+        console.print("[bold red]Could not find 'git' in the PATH. Is it installed?")
+        console.print("[bold red]Run command was: 'git --version '")
+        log.debug("git is not accessible!")
         return False
 
     return True
@@ -401,12 +449,12 @@ def create_github_labels(repo, labels: list) -> None:
     :param labels: A list of the new labels to be added
     """
     for label in labels:
-        log.debug(f'Creating Github label {label[0]}')
+        log.debug(f"Creating Github label {label[0]}")
         try:
             repo.create_label(name=label[0], color=label[1])
         except GithubException:
-            log.debug(f'Unable to create label {label[0]}')
-            console.print(f'[bold red]Unable to create label {label[0]} due to permissions')
+            log.debug(f"Unable to create label {label[0]}")
+            console.print(f"[bold red]Unable to create label {label[0]} due to permissions")
 
 
 def is_git_repo(path: Path) -> bool:
